==> falkon_3.0.0.orig.tar.xz: falkon-3.0.0/src/lib/bookmarks/bookmarksicon.h <==
/* ============================================================
* Falkon - Qt web browser
* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#ifndef BOOKMARKSICON_H
#define BOOKMARKSICON_H

#include <QUrl>

#include "clickablelabel.h"
#include "qzcommon.h"

class WebView;
class BookmarkItem;

class FALKON_EXPORT BookmarksIcon : public ClickableLabel
{
    Q_OBJECT
public:
    explicit BookmarksIcon(QWidget* parent = 0);

    void setWebView(WebView* view);
    void checkBookmark(const QUrl &url, bool forceCheck = false);

private Q_SLOTS:
    void bookmarksChanged();
    void speedDialChanged();

    void iconClicked();

private:
    void contextMenuEvent(QContextMenuEvent* ev);
    void mousePressEvent(QMouseEvent* ev);

    void setBookmarkSaved();
    void setBookmarkDisabled();

    WebView* m_view;
    BookmarkItem* m_bookmark;
    QUrl m_lastUrl;
};

#endif // BOOKMARKSICON_H

==> falkon_3.1.0.orig.tar.xz: falkon-3.1.0/src/lib/bookmarks/bookmarksicon.h <==
/* ============================================================
* Falkon - Qt web browser
* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#ifndef BOOKMARKSICON_H
#define BOOKMARKSICON_H

#include <QUrl>

#include "clickablelabel.h"
#include "qzcommon.h"

class WebView;
class BookmarkItem;

class FALKON_EXPORT BookmarksIcon : public ClickableLabel
{
    Q_OBJECT
public:
    explicit BookmarksIcon(QWidget* parent = 0);

    void setWebView(WebView* view);
    void checkBookmark(const QUrl &url, bool forceCheck = false);

private Q_SLOTS:
    void bookmarksChanged();
    void speedDialChanged();

    void iconClicked();

private:
    void contextMenuEvent(QContextMenuEvent* ev) override;
    void mousePressEvent(QMouseEvent* ev) override;

    void setBookmarkSaved();
    void setBookmarkDisabled();

    WebView* m_view;
    BookmarkItem* m_bookmark;
    QUrl m_lastUrl;
};

#endif // BOOKMARKSICON_H
